package com.ruoyi.manage.mapper;

import java.util.List;
import com.ruoyi.manage.domain.RecordInspection;
import org.springframework.stereotype.Repository;
/**
 * 巡检记录Mapper接口
 *
 * @author wangh
 * @date 2024-02-18
 */
@Repository
public interface RecordInspectionMapper
{
    /**
     * 查询巡检记录
     *
     * @param inspectionId 巡检记录主键
     * @return 巡检记录
     */
    public RecordInspection selectRecordInspectionByInspectionId(Long inspectionId);

    /**
     * 查询巡检记录列表
     *
     * @param recordInspection 巡检记录
     * @return 巡检记录集合
     */
    public List<RecordInspection> selectRecordInspectionList(RecordInspection recordInspection);

    /**
     * 新增巡检记录
     *
     * @param recordInspection 巡检记录
     * @return 结果
     */
    public int insertRecordInspection(RecordInspection recordInspection);

    /**
     * 修改巡检记录
     *
     * @param recordInspection 巡检记录
     * @return 结果
     */
    public int updateRecordInspection(RecordInspection recordInspection);

    /**
     * 删除巡检记录
     *
     * @param inspectionId 巡检记录主键
     * @return 结果
     */
    public int deleteRecordInspectionByInspectionId(Long inspectionId);

    /**
     * 批量删除巡检记录
     *
     * @param inspectionIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordInspectionByInspectionIds(String[] inspectionIds);
}
